@@ -69,8 +69,13 @@ class ResourceClass(object):
         :raises: ResourceClassNotFound if no such resource class was found
         """
         rc = context.rc_cache.all_from_string(name)
-        obj = cls(context, id=rc['id'], name=rc['name'],
-                  updated_at=rc['updated_at'], created_at=rc['created_at'])
+        obj = cls(
+            context,
+            id=rc.id,
+            name=rc.name,
+            updated_at=rc.updated_at,
+            created_at=rc.created_at,
+        )
         return obj
 
     @staticmethod
@@ -215,18 +220,18 @@ def ensure_sync(ctx):
 def get_all(context):
     """Get a list of all the resource classes in the database."""
     resource_classes = context.rc_cache.get_all()
-    return [ResourceClass(context, **rc) for rc in resource_classes]
+    return [ResourceClass(context, **rc._mapping) for rc in resource_classes]
 
 
 @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
 @db_api.placement_context_manager.writer
 def _resource_classes_sync(ctx):
     # Create a set of all resource class in the os_resource_classes library.
-    sel = sa.select([_RC_TBL.c.name])
+    sel = sa.select(_RC_TBL.c.name)
     res = ctx.session.execute(sel).fetchall()
     db_classes = [r[0] for r in res if not orc.is_custom(r[0])]
     LOG.debug("Found existing resource classes in db: %s", db_classes)
-    # Determine those resource clases which are in os_resource_classes but not
+    # Determine those resource classes which are in os_resource_classes but not
     # currently in the database, and insert them.
     batch_args = [{'name': str(name), 'id': index}
                   for index, name in enumerate(orc.STANDARDS)
